/*
 * File : layer.C
 *
 * This file provides the default method implementations for
 * the layer base class.
 */

#include "errorCodes.h"
#include "trace.h"
#include "layer.h"
#include "dataPacket.h"

DEFINE_TRACE_MODULE(layerModule,"layerModule");

/*
 * Function : layer
 *
 * Description : This is the constructor. Initializes
 *	variables.
 */

layer::layer()
{
	_blockRecv = FALSE;
	_blockXmit = FALSE;
}

/*
 * Function : Command(int, int)
 *
 * Description : Provides default implementation. 
 *	Just returns an error code of not implemented.
 */

void 
layer::Command(int , int &errorCode)
{
	TRACE(layerModule,1,("Entering Command_int*\n"));
	errorCode = codeNotImplemented;
}

/*
 * Function : Command(int, int, int, int)
 *
 * Description : Provides default implementation. 
 *	Just returns an error code of not implemented.
 */

void 
layer::Command(int , int &errorCode, int)
{
	TRACE(layerModule,1,("Command_int_int\n"));
	errorCode = codeNotImplemented;
}

/*
 * Function : Command(int, int, dataPacket *)
 *
 * Description : Provides default implementation. 
 *	Just returns an error code of not implemented.
 */

void 
layer::Command(int , int &errorCode,dataPacket *data)
{
	TRACE(layerModule,1,("Command_int_int_dataPacket*\n"));
	data->Print();
	errorCode = codeNotImplemented;
}
