/*
 * File : trace.C
 *
 * Description : This file contains definitions of member 
 * functions of the trace and traceManager classes.
 */

#include <stdio.h> 
#include <iostream.h>
#include <stdarg.h>
#include <string.h>
#include "trace.h"

/*
 * Initialize static data members
 */

int traceManager::_index  = 0;
trace *traceManager::_modules[MaxModules]  = {0};		

/*
 * Function : trace
 *
 * Description : Constructor - initializes private data, adds
 * itself to the traceManager
 */

trace::trace(const char *name):
	_on(FALSE),
	_level(0),
	_name(0)
{
	_name = new char[strlen(name)+1];
	strcpy(_name,(char *)name);
	traceManager::AddModule(this);
}

/*
 * Function : ~trace
 *
 * Description : Destructor - frees memory
 */

trace::~trace(void)
{
	if ( _name )
		delete _name;	
}

/*
 * Function : PrintTraceInfo
 *
 * Description : Takes in a variable format, and a
 * indefinite number of arguments and prints out the
 * information. Note that defining NTRACE at compile
 * time would remove the code for this function.
 */

void 
trace::PrintTraceInfo(const char * format, ...)
{
#ifndef NTRACE

	char	buf[500];

	va_list pvar;
	va_start(pvar, format);
	vsprintf(buf,(char *)format,pvar);
	fprintf(stderr,"%s",buf);
	va_end(pvar);
	
	cerr << flush;

#endif
}

/*
 * Function : PrintModuleName
 *
 * Description : Prints out the module name
 */

void
trace::PrintModuleName(void)
{
#ifndef NTRACE
	fprintf(stderr,"%s::",_name);
#endif
}

/*
 * Function : IsModuleOn
 *
 * Description : returns the value of the _on data member
 */

Boolean
trace::IsModuleOn(void)
{
	return _on;
}

/*
 * Function : Level
 *
 * Description : returns the value of the _level data member
 */

int
trace::Level(void)
{
	return _level;
}

/*
 * Function : Name
 *
 * Description : returns the value of the _name data member
 */

const char *
trace::Name(void)
{
	return _name;
}
	

/*
 * Function : SetTrace
 *
 * Description : Sets the tracing level and starts tracing. 
 */

void		
trace::SetTrace(int level)
{
	_on = TRUE;
	_level = level;
}

/*
 * Function : ResetTrace
 *
 * Description : Resets the tracing level to 0, and stops
 * tracing. 
 */

void
trace::ResetTrace(void)
{
	_level = 0;
	_on = FALSE;
}

/*
 * Function : AddModule
 *
 * Description : Adds a new trace object to the array
 * of pointers in the traceManager
 */


void
traceManager::AddModule(trace *module) 
{
	if ( _index < MaxModules )
		_modules[_index++] = module;	
}

/*
 * Function : PrintModules
 *
 * Description : For each module registered with the
 * traceManager, this function prints out the name
 * of the module, followed by the index of the module
 * into the array of trace object pointers.
 */

void
traceManager::PrintModules()
{
	for(int i = 0; i < _index; i++ )
		cout << _modules[i]->Name() << "(" << i << ")\n";
	cout << flush;
}

/*
 * Function : GetModule
 *
 * Description : Given an index, the function returns
 * a pointer to the trace object.
 */

trace *
traceManager::GetModule(int index)
{
	if ( index >= 0 && index < _index )
		return _modules[index];
	else
		return 0;
}

